/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.scripting.thymeleaf.internal;

import javax.script.Bindings;

import org.apache.sling.api.resource.Resource;
import org.apache.sling.api.scripting.SlingBindings;
import org.apache.sling.scripting.api.BindingsValuesProvider;
import org.osgi.service.component.annotations.Component;

@Component(
    property = {
        "javax.script.name=thymeleaf"
    }
)
public class ThymeleafBindingsValuesProvider implements BindingsValuesProvider {

    private static final String PROPERTIES = "properties";

    @Override
    public void addBindings(final Bindings bindings) {
        if (!bindings.containsKey(PROPERTIES)) {
            final Resource resource = (Resource) bindings.get(SlingBindings.RESOURCE);
            if (resource != null) {
                bindings.put(PROPERTIES, resource.getValueMap());
            }
        }
    }

}
